@@ -1,8 +1,14 @@
 #' Plot Colour Scheme
 #'
+#' \code{plot} allows to quickly display a colour scheme returned by
+#' \code{\link{colour}}.
+#'
 #' \code{plot_scheme} shows colours in a plot.
 #'
 #' \code{plot_map} produces a diagnostic map for a given colour scheme.
+#'
+#' \code{plot_scheme_colorblind} shows colours in a plot with different types
+#' of simulated color blindness.
 #' @param x A \code{\link{character}} vector of colours.
 #' @param colours A \code{\link{logical}} scalar: should the hexadecimal
 #' representation of the colours be displayed?
@@ -11,13 +17,33 @@
 #' @param size A \code{\link{numeric}} value giving the amount by which
 #' plotting text should be magnified relative to the default.
 #' Works the same as \code{cex} parameter of \code{\link[graphics]{par}}.
+#' @param ... Currently not used.
 #' @example inst/examples/ex-plot.R
-#' @author N. Frerebeau
+#' @author N. Frerebeau, V. Arel-Bundock
 #' @family diagnostic tools
 #' @name plot
 #' @rdname plot
 NULL
 
+#' @rdname plot
+#' @export
+plot.colour_scheme <- function(x, ...) {
+  # Save and restore graphical parameters
+  old_par <- graphics::par(no.readonly = TRUE)
+  on.exit(graphics::par(old_par))
+
+  n <- length(x)
+  graphics::par(mar = c(0, 0, 0, 0) + 0.1, xaxs = "i", yaxs = "i")
+  graphics::plot(
+    x = NULL, y = NULL,
+    xlim = c(0, n), ylim = c(0, 1),
+    xlab = "", ylab = "", axes = FALSE
+  )
+  graphics::rect(xleft = seq(0, n - 1), xright = seq(1, n),
+                 ybottom = 0.25, ytop = 0.75, col = x, border = NA)
+  if (n < 25) graphics::abline(v = seq(1, n), col = "#D3D3D3", lwd = 0.25)
+}
+
 #' @rdname plot
 #' @export
 plot_scheme <- function(x, colours = FALSE, names = FALSE, size = 1) {
@@ -28,24 +54,38 @@ plot_scheme <- function(x, colours = FALSE, names = FALSE, size = 1) {
   old_par <- graphics::par(no.readonly = TRUE)
   on.exit(graphics::par(old_par))
 
-  n <- length(x) # Number of colours
   info <- colours && names
+  missing <- attr(x, "missing")
+  bad_data <- !is.null(missing) && !is.na(missing)
+  if (bad_data) x <- c(x, missing)
+
+  n <- length(x) # Number of colours
   p <- seq(from = 1, by = 0.75, length.out = n)
   q <- 1 - 0.43 * rep(c(0, 1), length.out = n)
 
   graphics::par(mar = c(0, 0, 0, 0) + 0.1, xaxs = "i", yaxs = "i")
   graphics::plot(
     x = NULL, y = NULL,
-    xlim = c(0.5, max(p) + 0.5), ylim = c(0, 1.5),
+    xlim = c(0.5, max(p) + 0.5 + bad_data / 2), ylim = c(0, 1.5),
     xlab = "", ylab = "", axes = FALSE, asp = 1
   )
 
-  for (i in seq_along(x)) {
-    even <- i %% 2 == 0
+  for (i in seq_len(n - bad_data)) {
+    #even <- i %% 2 == 0
     draw_hexagon(x = p[[i]], y = q[[i]], r = 0.5, border = NULL, fill = x[[i]])
   }
+  if (bad_data) {
+    draw_circle(x = p[[n]] + 0.5, y = q[[n]], r = 0.5, n = 200,
+                border = NULL, fill = missing)
+  }
   delta <- ifelse(colours && names && !is.null(names(x)), 0.1, 0)
   if (colours) {
+    if (bad_data) {
+      graphics::text(x = p[[n]] + 0.5, y = q[[n]], labels = missing, cex = size)
+      x <- utils::head(x, -1)
+      p <- utils::head(p, -1)
+      q <- utils::head(q, -1)
+    }
     graphics::text(x = p, y = q - delta * info, labels = x, cex = size)
   }
   if (names && !is.null(names(x))) {
@@ -138,3 +178,48 @@ draw_hexagon <- function(x = 0, y = 0, r = 0.5, border = NULL, fill = NA) {
     col = fill
   )
 }
+draw_circle <- function(x = 0, y = 0, r = 0.5, n = 200,
+                        border = NULL, fill = NA) {
+  theta <- seq(0, 2 * pi, length.out = n)
+  graphics::polygon(
+    x = r * cos(theta) + x,
+    y = r * sin(theta) + y,
+    border = border,
+    col = fill
+  )
+}
+
+#' @rdname plot
+#' @export
+plot_scheme_colourblind <- function(x) {
+  # Validation
+  if (!is.atomic(x) || !is.character(x))
+    stop("x must be a character vector of colours.")
+
+  n <- length(x)
+  col <- c(x, anomalize(x, 'deuteranopia'), anomalize(x, 'protanopia'),
+           anomalize(x, 'tritanopia'), anomalize(x, 'achromatopsia'))
+  xcoord <- seq(0, 1, length.out = n + 1)
+  ycoord <- rep(c(.8, .6, .4, .2, 0), each = n)
+  grid::grid.newpage()
+  grid::grid.rect(
+    x = grid::unit(utils::head(xcoord, -1), "npc"),
+    y = grid::unit(ycoord, "npc"),
+    width = grid::unit(1 / n, "npc"),
+    height = grid::unit(0.7 / 5, "npc"),
+    hjust = 0,
+    vjust = 0,
+    gp = grid::gpar(fill = col, col = col)
+  )
+  grid::grid.text(
+    label = c("Palette", "Deuteranopia", "Protanopia", "Tritanopia",
+              "Achromatopsia"),
+    x = grid::unit(0, 'npc'),
+    y = grid::unit(c(0.97, 0.77, 0.57, 0.37, 0.17), "npc"),
+    hjust = 0
+  )
+}
+
+#' @rdname plot
+#' @export
+plot_scheme_colorblind <- plot_scheme_colourblind
